pub struct RemoteSystemDaemon { /* private fields */ }Implementations
Sourceimpl RemoteSystemDaemon
impl RemoteSystemDaemon
pub fn new( system: ActorSystem, registry: SerializerRegistry, endpoint_manager: EndpointManager, local_uid: u64, ) -> Arc<Self> ⓘ
pub fn registry(&self) -> &SerializerRegistry
pub fn system(&self) -> &ActorSystem
Sourcepub fn register(&self, path: ActorPath, dispatch: LocalDispatch)
pub fn register(&self, path: ActorPath, dispatch: LocalDispatch)
Register a dispatcher for inbound messages addressed to path.
pub fn unregister(&self, path: &ActorPath)
pub fn clear(&self)
pub fn dispatch_user( &self, path: &ActorPath, manifest: &str, serializer_id: u32, bytes: &[u8], ) -> Result<(), SerializeError>
pub fn dispatch_system(&self, path: &ActorPath, msg: RemoteSystemMsg)
Sourcepub fn notify_terminated(&self, path: &ActorPath)
pub fn notify_terminated(&self, path: &ActorPath)
Notify all remote watchers of path that the actor has stopped.